    #region Copyright
// Copyright Syncfusion Inc. 2001 - 2014. All rights reserved.
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// licensing@syncfusion.com. Any infringement will be prosecuted under
// applicable laws. 
#endregion

namespace MVCSampleBrowser.Models
{
    using System.Collections.Generic;
    using System.ComponentModel.DataAnnotations;
    using System.ComponentModel.DataAnnotations.Schema;

    /// <summary>
    /// Student Class
    /// </summary>
    
    public class Homeroom
    {
        [Key]
        [DatabaseGenerated(DatabaseGeneratedOption.Identity)]
        public int HomeroomId { get; set; }
        public string Description { get; set; }
    }

    public class Student
    {
        #region Properties
        /// <summary>
        /// Gets or sets the student Name
        /// </summary>
        public long UniversityCode { get; set; }

        /// <summary>
        /// Gets or sets the course title
        /// </summary>
        public string Title { get; set; }
        [ForeignKey("Homeroom")]
        public int? HomeroomId { get; set; }


        public virtual Homeroom Homeroom { get; set; }

        /// <summary>
        /// Gets or sets the duration in days of the course
        /// </summary>                
        public int Duration { get; set; }

        /// <summary>
        /// Gets or sets course fees
        /// </summary>        
        public double CourseFees { get; set; }

        /// <summary>
        /// Gets or sets CGPA
        /// </summary>        
        public double CGPA { get; set; }

        #endregion
    }
  
    /// <summary>
    /// StudentPerformance class
    /// </summary>
    public class StudentPerformance
    {
        #region Properties
        /// <summary>
        /// Gets or sets the student Name
        /// </summary>
        public long UniversityCode { get; set; }

        /// <summary>
        /// Gets or set DBMS marks
        /// </summary>
        public int DBMS { get; set; }

        /// <summary>
        /// Gets or set CloudComputing marks
        /// </summary>
        public int CloudComputing { get; set; }

        /// <summary>
        /// Gets or set DataStructures marks
        /// </summary>
        public int DataStructures { get; set; }
        
        /// <summary>
        /// Gets or sets CGPA
        /// </summary>        
        public double CGPA { get; set; }

        #endregion
    }

    /// <summary>
    /// StudentDataContext Class
    /// </summary>
    public class StudentDataContext
    {
        #region Properties

        /// <summary>
        /// Gets  the courses in a IQueryable format
        /// </summary>
        public List<Student> Student
        {
            get
            {
                List<Student> student = new List<Student>();
                Student stu = new Student();
                int code = 10000;
                for (long i = 0; i < 1200; i++)
                {
                    Student[] s = new Student[10];
                    s[0] = new Student() { UniversityCode = code + 1, HomeroomId= code+1,  CourseFees = 2000.00, CGPA = 7.52, Duration = 90, Title = "Distributed Component Architecture" };
                    s[1] = new Student() { UniversityCode = code + 2, HomeroomId = code + 2, CourseFees = 1000.00, CGPA = 9.55, Duration = 60, Title = "Data Structures" };
                    s[2] = new Student() { UniversityCode = code + 3, HomeroomId = code + 3, CourseFees = 1750.00, CGPA = 9.03, Duration = 75, Title = "Neural Networks" };
                    s[3] = new Student() { UniversityCode = code + 4, HomeroomId = code + 4, CourseFees = 2000.00, CGPA = 8.91, Duration = 90, Title = "Genetic Algorithms" };
                    s[4] = new Student() { UniversityCode = code + 5, HomeroomId = code + 5, CourseFees = 1000.00, CGPA = 9.55, Duration = 30, Title = "Grid Computing" };
                    s[5] = new Student() { UniversityCode = code + 6, HomeroomId = code + 6, CourseFees = 2500.00, CGPA = 9.87, Duration = 60, Title = "Cloud Computing" };
                    s[6] = new Student() { UniversityCode = code + 7, HomeroomId = code + 7, CourseFees = 1500.00, CGPA = 9.75, Duration = 90, Title = "Enterprise Computing" };
                    s[7] = new Student() { UniversityCode = code + 8, HomeroomId = code + 8, CourseFees = 1250.00, CGPA = 9.66, Duration = 45, Title = "Mobile Computing" };
                    s[8] = new Student() { UniversityCode = code + 9, HomeroomId = code + 9, CourseFees = 1000.00, CGPA = 8.33, Duration = 60, Title = "WAP and XML" };
                    s[9] = new Student() { UniversityCode = code + 10, HomeroomId = code + 10, CourseFees = 1500.00, CGPA = 8.66, Duration = 75, Title = "Design Patterns" };
                    foreach (Student studnt in s)
                    {
                        student.Add(studnt);
                    }

                    code += 10;
                }

                return student;
            }
        }

        /// <summary>
        /// Gets the JSONStudent
        /// </summary>
        public List<Student> JSONStudent
        {
            get
            {
                List<Student> student = new List<Student>();
                Student stu = new Student();
                int code = 10000;
                for (long i = 0; i < 1000; i++)
                {
                    Student[] s = new Student[10];
                    s[0] = new Student() { UniversityCode = code + 1, CourseFees = 2000.00, CGPA = 7.52, Duration = 90, Title = "Distributed Component Architecture" };
                    s[1] = new Student() { UniversityCode = code + 2, CourseFees = 1000.00, CGPA = 9.55, Duration = 60, Title = "Data Structures" };
                    s[2] = new Student() { UniversityCode = code + 3, CourseFees = 1750.00, CGPA = 9.03, Duration = 75, Title = "Neural Networks" };
                    s[3] = new Student() { UniversityCode = code + 4, CourseFees = 2000.00, CGPA = 8.91, Duration = 90, Title = "Genetic Algorithms" };
                    s[4] = new Student() { UniversityCode = code + 5, CourseFees = 1000.00, CGPA = 9.55, Duration = 30, Title = "Grid Computing" };
                    s[5] = new Student() { UniversityCode = code + 6, CourseFees = 2500.00, CGPA = 9.87, Duration = 60, Title = "Cloud Computing" };
                    s[6] = new Student() { UniversityCode = code + 7, CourseFees = 1500.00, CGPA = 9.75, Duration = 90, Title = "Enterprise Computing" };
                    s[7] = new Student() { UniversityCode = code + 8, CourseFees = 1250.00, CGPA = 9.66, Duration = 45, Title = "Mobile Computing" };
                    s[8] = new Student() { UniversityCode = code + 9, CourseFees = 1000.00, CGPA = 8.33, Duration = 60, Title = "WAP and XML" };
                    s[9] = new Student() { UniversityCode = code + 10, CourseFees =1500.00, CGPA = 8.66, Duration = 75, Title = "Design Patterns" };
                    foreach (Student studnt in s)
                    {
                        student.Add(studnt);
                    }

                    code += 10;
                }

                return student;
            }
        }

        /// <summary>
        /// Gets the PassThroughStudent
        /// </summary>
        public List<Student> PassThroughStudent
        {
            get
            {
                List<Student> student = new List<Student>();
                Student stu = new Student();
                int code = 10000;
                for (long i = 0; i < 1000; i++)
                {
                    Student[] s = new Student[10];
                    s[0] = new Student() { UniversityCode = code + 1, CourseFees = 2000.00, CGPA = 7.52, Duration = 90, Title = "Distributed Component Architecture" };
                    s[1] = new Student() { UniversityCode = code + 2, CourseFees = 1000.00, CGPA = 9.55, Duration = 60, Title = "Data Structures" };
                    s[2] = new Student() { UniversityCode = code + 3, CourseFees = 1750.00, CGPA = 9.03, Duration = 75, Title = "Neural Networks" };
                    s[3] = new Student() { UniversityCode = code + 4, CourseFees = 2000.00, CGPA = 8.91, Duration = 90, Title = "Genetic Algorithms" };
                    s[4] = new Student() { UniversityCode = code + 5, CourseFees = 1000.00, CGPA = 9.55, Duration = 30, Title = "Grid Computing" };
                    s[5] = new Student() { UniversityCode = code + 6, CourseFees = 2500.00, CGPA = 9.87, Duration = 60, Title = "Cloud Computing" };
                    s[6] = new Student() { UniversityCode = code + 7, CourseFees = 1500.00, CGPA = 9.75, Duration = 90, Title = "Enterprise Computing" };
                    s[7] = new Student() { UniversityCode = code + 8, CourseFees = 1250.00, CGPA = 9.66, Duration = 45, Title = "Mobile Computing" };
                    s[8] = new Student() { UniversityCode = code + 9, CourseFees = 1000.00, CGPA = 8.33, Duration = 60, Title = "WAP and XML" };
                    s[9] = new Student() { UniversityCode = code + 10, CourseFees =1500.00, CGPA = 8.66, Duration = 75, Title = "Design Patterns" };
                    foreach (Student studnt in s)
                    {
                        student.Add(studnt);
                    }

                    code += 10;
                }

                return student;
            }
        }

        /// <summary>
        /// Gets of sets the AutoFormatStudent
        /// </summary>
        public List<Student> AutoFormatStudent
        {
            get
            {
                List<Student> student = new List<Student>();
                Student stu = new Student();
                int code = 10000;
                for (long i = 0; i < 100; i++)
                {
                    Student[] s = new Student[10];
                    s[0] = new Student() { UniversityCode = code + 1, CourseFees = 2000.00, CGPA = 7.52, Duration = 90, Title = "Distributed Component Architecture" };
                    s[1] = new Student() { UniversityCode = code + 2, CourseFees = 1000.00, CGPA = 9.55, Duration = 60, Title = "Data Structures" };
                    s[2] = new Student() { UniversityCode = code + 3, CourseFees = 1750.00, CGPA = 9.03, Duration = 75, Title = "Neural Networks" };
                    s[3] = new Student() { UniversityCode = code + 4, CourseFees = 2000.00, CGPA = 8.91, Duration = 90, Title = "Genetic Algorithms" };
                    s[4] = new Student() { UniversityCode = code + 5, CourseFees = 1000.00, CGPA = 9.55, Duration = 30, Title = "Grid Computing" };
                    s[5] = new Student() { UniversityCode = code + 6, CourseFees = 2500.00, CGPA = 9.87, Duration = 60, Title = "Cloud Computing" };
                    s[6] = new Student() { UniversityCode = code + 7, CourseFees = 1500.00, CGPA = 9.75, Duration = 90, Title = "Enterprise Computing" };
                    s[7] = new Student() { UniversityCode = code + 8, CourseFees = 1250.00, CGPA = 9.66, Duration = 45, Title = "Mobile Computing" };
                    s[8] = new Student() { UniversityCode = code + 9, CourseFees = 1000.00, CGPA = 8.33, Duration = 60, Title = "WAP and XML" };
                    s[9] = new Student() { UniversityCode = code + 10, CourseFees =1500.00, CGPA = 8.66, Duration = 75, Title = "Design Patterns" };
                    foreach (Student studnt in s)
                    {
                        student.Add(studnt);
                    }

                    code += 10;
                }

                return student;
            }
        }
        #endregion
    }
}
